==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/src/Uncertainty/Algorithm/MetaModel/FunctionalChaos/SequentialStrategy.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  SequentialStrategy.cxx
 *  @brief An implementation returning the set of polynomials in sequence
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 11:21:38 +0200 (Wed, 21 May 2008) $
 *  Id:      $Id: Object.cxx 815 2008-05-21 09:21:38Z dutka $
 */
#include "SequentialStrategy.hxx"
#include "Log.hxx"
#include "OSS.hxx"
#include "PersistentObjectFactory.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      CLASSNAMEINIT(SequentialStrategy);

      static Base::Common::Factory<SequentialStrategy> RegisteredFactory("SequentialStrategy");

      typedef Base::Common::Log Log;

      /* Default constructor */
      SequentialStrategy::SequentialStrategy()
	: AdaptiveStrategyImplementation(),
	  currentVectorIndex_(0)
      {
	// Nothing to do
      }

      
      /* Constructor from an orthogonal basis */
      SequentialStrategy::SequentialStrategy(const OrthogonalBasis & basis,
					     const UnsignedLong maximumDimension,
					     const Bool verbose)
	: AdaptiveStrategyImplementation(basis, maximumDimension),
	  currentVectorIndex_(0),
	  verbose_(verbose)
      {
	// Nothing to do
      }

      
      /* Compute initial basis for the approximation */
      void SequentialStrategy::computeInitialBasis()
      {
	// Start with the first vector
	currentVectorIndex_ = 0;
	Psi_k_p_ = NumericalMathFunctionCollection(1, basis_.build(currentVectorIndex_));
	I_p_.add(currentVectorIndex_);
	++currentVectorIndex_;
      }

      /* Update the basis for the next iteration of approximation */
      void SequentialStrategy::updateBasis(const NumericalPoint & alpha_k_p_,
					   const NumericalScalar residual_p_)
      {
	if (verbose_)
	  {
	    Log::Info(OSS() << "initial state:");
	    Log::Info(OSS() << "  vector index=" << currentVectorIndex_);
	    Log::Info(OSS() << "  coeffs  size=" << alpha_k_p_.getSize());
	    Log::Info(OSS() << "  coeffs      =" << alpha_k_p_);
	    Log::Info(OSS() << "  I_p     size=" << I_p_.getSize());
	    Log::Info(OSS() << "  I_p         =" << I_p_);
	  }
	// If we have not generated all the vectors, go to the next one
	if (currentVectorIndex_ < maximumDimension_)
	  {
	    const NumericalMathFunction newVector(basis_.build(currentVectorIndex_));
	    Psi_k_p_.add(newVector);
	    I_p_.add(currentVectorIndex_);
	    addedPsi_k_indices_ = Indices(1, I_p_.getSize() - 1);
	    ++currentVectorIndex_;
	  }
	else
	  {
	    addedPsi_k_indices_   = Indices(0);
	  }
	// No vector is removed
	removedPsi_k_indices_ = Indices(0);
	if (verbose_)
	  {
	    Log::Info(OSS() << "final state:");
	    Log::Info(OSS() << "  vector index=" << currentVectorIndex_);
	    Log::Info(OSS() << "  coeffs  size=" << alpha_k_p_.getSize());
	    Log::Info(OSS() << "  coeffs      =" << alpha_k_p_);
	    Log::Info(OSS() << "  I_p     size=" << I_p_.getSize());
	    Log::Info(OSS() << "  I_p         =" << I_p_);
	  }
      }


      /* Virtual constructor */
      SequentialStrategy * SequentialStrategy::clone() const
      {
	return new SequentialStrategy(*this);
      }


      /* String converter */
      String SequentialStrategy::__repr__() const
      {
	return OSS() << "class=" << getClassName();
      }


      /* Method save() stores the object through the StorageManager */
      void SequentialStrategy::save(const StorageManager::Advocate & adv) const
      {
	AdaptiveStrategyImplementation::save(adv);
      }


      /* Method load() reloads the object from the StorageManager */
      void SequentialStrategy::load(const StorageManager::Advocate & adv)
      {
	AdaptiveStrategyImplementation::load(adv);
      }



    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/src/Uncertainty/Algorithm/MetaModel/FunctionalChaos/SequentialStrategy.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  SequentialStrategy.cxx
 *  @brief An implementation returning the set of polynomials in sequence
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-05-21 11:21:38 +0200 (Wed, 21 May 2008) $
 *  Id:      $Id: Object.cxx 815 2008-05-21 09:21:38Z dutka $
 */
#include "SequentialStrategy.hxx"
#include "Log.hxx"
#include "OSS.hxx"
#include "PersistentObjectFactory.hxx"

namespace OpenTURNS
{

  namespace Uncertainty
  {

    namespace Algorithm
    {

      CLASSNAMEINIT(SequentialStrategy);

      static Base::Common::Factory<SequentialStrategy> RegisteredFactory("SequentialStrategy");

      typedef Base::Common::Log Log;

      /* Default constructor */
      SequentialStrategy::SequentialStrategy()
	: AdaptiveStrategyImplementation(),
	  currentVectorIndex_(0)
      {
	// Nothing to do
      }

      
      /* Constructor from an orthogonal basis */
      SequentialStrategy::SequentialStrategy(const OrthogonalBasis & basis,
					     const UnsignedLong maximumDimension,
					     const Bool verbose)
	: AdaptiveStrategyImplementation(basis, maximumDimension),
	  currentVectorIndex_(0),
	  verbose_(verbose)
      {
	// Nothing to do
      }

      
      /* Compute initial basis for the approximation */
      void SequentialStrategy::computeInitialBasis()
      {
	// Start with the first vector
	currentVectorIndex_ = 0;
	Psi_k_p_ = NumericalMathFunctionCollection(1, basis_.build(currentVectorIndex_));
	I_p_ = Indices(1, currentVectorIndex_);
	addedPsi_k_ranks_ = Indices(1, 0);
	removedPsi_k_ranks_ = Indices(0);
	conservedPsi_k_ranks_ = Indices(0);
	++currentVectorIndex_;
      }

      /* Update the basis for the next iteration of approximation */
      void SequentialStrategy::updateBasis(const NumericalPoint & alpha_k_p_,
					   const NumericalScalar residual_p_)
      {
	if (verbose_)
	  {
	    Log::Info(OSS() << "initial state:");
	    Log::Info(OSS() << "  vector index=" << currentVectorIndex_);
	    Log::Info(OSS() << "  coeffs  size=" << alpha_k_p_.getSize());
	    Log::Info(OSS() << "  coeffs      =" << alpha_k_p_);
	    Log::Info(OSS() << "  I_p     size=" << I_p_.getSize());
	    Log::Info(OSS() << "  I_p         =" << I_p_);
	  }
	// If we have not generated all the vectors, go to the next one
	// All the previous vectors are kept
	conservedPsi_k_ranks_ = Indices(I_p_.getSize());
	conservedPsi_k_ranks_.fill();
	if (currentVectorIndex_ < maximumDimension_)
	  {
	    const NumericalMathFunction newVector(basis_.build(currentVectorIndex_));
	    Psi_k_p_.add(newVector);
	    I_p_.add(currentVectorIndex_);
	    addedPsi_k_ranks_ = Indices(1, I_p_.getSize() - 1);
	    ++currentVectorIndex_;
	  }
	else
	  {
	    addedPsi_k_ranks_   = Indices(0);
	  }
	// No vector is removed
	removedPsi_k_ranks_ = Indices(0);
	if (verbose_)
	  {
	    Log::Info(OSS() << "final state:");
	    Log::Info(OSS() << "  vector index=" << currentVectorIndex_);
	    Log::Info(OSS() << "  coeffs  size=" << alpha_k_p_.getSize());
	    Log::Info(OSS() << "  coeffs      =" << alpha_k_p_);
	    Log::Info(OSS() << "  I_p     size=" << I_p_.getSize());
	    Log::Info(OSS() << "  I_p         =" << I_p_);
	  }
      }


      /* Virtual constructor */
      SequentialStrategy * SequentialStrategy::clone() const
      {
	return new SequentialStrategy(*this);
      }


      /* String converter */
      String SequentialStrategy::__repr__() const
      {
	return OSS() << "class=" << getClassName();
      }


      /* Method save() stores the object through the StorageManager */
      void SequentialStrategy::save(StorageManager::Advocate & adv) const
      {
	AdaptiveStrategyImplementation::save(adv);
      }


      /* Method load() reloads the object from the StorageManager */
      void SequentialStrategy::load(StorageManager::Advocate & adv)
      {
	AdaptiveStrategyImplementation::load(adv);
      }



    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
